==> dokuwiki-2013.12.08.tgz: dokuwiki/lib/plugins/usermanager/lang/hu/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Sandor TIHANYI <stihanyi+dw@gmail.com>
 * @author Siaynoq Mage <siaynoqmage@gmail.com>
 * @author schilling.janos@gmail.com
 * @author Szabó Dávid <szabo.david@gyumolcstarhely.hu>
 * @author Sándor TIHANYI <stihanyi+dw@gmail.com>
 * @author David Szabo <szabo.david@gyumolcstarhely.hu>
 * @author Marton Sebok <sebokmarton@gmail.com>
 * @author Serenity87HUN <anikototh87@gmail.com>
 */
$lang['menu']                  = 'Felhasználók kezelése';
$lang['noauth']                = '(A felhasználói azonosítás nem működik.)';
$lang['nosupport']             = '(A felhasználók kezelése nem támogatott.)';
$lang['badauth']               = 'nem érvényes autentikációs technika';
$lang['user_id']               = 'Felhasználói azonosító';
$lang['user_pass']             = 'Jelszó';
$lang['user_name']             = 'Név';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Csoportok';
$lang['field']                 = 'Mező';
$lang['value']                 = 'Érték';
$lang['add']                   = 'Hozzáadás';
$lang['delete']                = 'Törlés';
$lang['delete_selected']       = 'Kiválasztottak törlése';
$lang['edit']                  = 'Szerkesztés';
$lang['edit_prompt']           = 'A felhasználó szerkesztése';
$lang['modify']                = 'Változások mentése';
$lang['search']                = 'Keresés';
$lang['search_prompt']         = 'Keresés';
$lang['clear']                 = 'Keresési szűrés törlése';
$lang['filter']                = 'Szűrés';
$lang['export_all']            = 'Összes felhasználó exportálása (CSV)';
$lang['export_filtered']       = 'Kiválasztott felhasználók exportálása (CSV)';
$lang['import']                = 'Új felhasználók importálása';
$lang['line']                  = 'Sor száma';
$lang['error']                 = 'Hibaüzenet';
$lang['summary']               = '%1$d-%2$d. felhasználók megjelenítése a(z) %3$d megtalált felhasználóból. %4$d felhasználó van összesen.';
$lang['nonefound']             = 'Nincs ilyen felhasználó. %d felhasználó van összesen.';
$lang['delete_ok']             = '%d felhasználó törölve.';
$lang['delete_fail']           = '%d felhasználót nem sikerült törölni.';
$lang['update_ok']             = 'A felhasználó adatait sikeresen elmentettem.';
$lang['update_fail']           = 'A felhasználó adatainak mentése nem sikerült.';
$lang['update_exists']         = 'A felhasználói azonosító változtatása nem sikerült, a megadott azonosító (%s) már létezik. (A többi változtatás mentve.)';
$lang['start']                 = 'első';
$lang['prev']                  = 'előző';
$lang['next']                  = 'következő';
$lang['last']                  = 'utolsó';
$lang['edit_usermissing']      = 'A kiválasztott felhasználót nem találom, a felhasználói nevét törölték vagy megváltoztatták.';
$lang['user_notify']           = 'Felhasználó értesítése';
$lang['note_notify']           = 'Csak akkor küld értesítő e-mailt, ha a felhasználó új jelszót kapott.';
$lang['note_group']            = 'Ha nincs csoport meghatározva, az új felhasználó az alapértelmezett csoportba (%s) kerül.';
$lang['note_pass']             = 'Ha a baloldali mező üres és a felhasználó értesítés aktív, akkor a jelszót a rendszer generálja.';
$lang['add_ok']                = 'A felhasználó sikeresen hozzáadva.';
$lang['add_fail']              = 'A felhasználó hozzáadása nem sikerült.';
$lang['notify_ok']             = 'Értesítő levél elküldve.';
$lang['notify_fail']           = 'Nem sikerült az értesítő levelet elküldeni.';
$lang['import_userlistcsv']    = 'Felhasználók listája fájl (CSV)';
$lang['import_header']         = 'Legutóbbi importálás - Hibák';
$lang['import_success_count']  = 'Felhasználók importálása: %d felhasználót találtunk, ebből %d sikeresen importálva.';
$lang['import_failure_count']  = 'Felhasználók importálása: %d sikertelen. A sikertelenség okait lejjebb találod.';
$lang['import_error_fields']   = 'Túl kevés mezőt adtál meg, %d darabot találtunk, legalább 4-re van szükség.';
$lang['import_error_baduserid'] = 'Felhasználói azonosító hiányzik';
$lang['import_error_badname']  = 'Nem megfelelő név';
$lang['import_error_badmail']  = 'Nem megfelelő e-mailcím';
$lang['import_error_upload']   = 'Sikertelen importálás. A csv fájl nem feltölthető vagy üres.';
$lang['import_error_readfail'] = 'Sikertelen importálás. A feltöltött fájl nem olvasható.';
$lang['import_error_create']   = 'Ez a felhasználó nem hozható létre';
$lang['import_notify_fail']    = 'Az értesítő e-mail nem küldhető el az alábbi importált felhasználónak: %s e-mailcíme: %s.';
$lang['import_downloadfailures'] = 'Töltsd le a hibákat tartalmazó fájlt CSV formátumban, hogy ki tudd javítani a hibákat';

==> dokuwiki-2024.02.06.tgz: dokuwiki/lib/plugins/usermanager/lang/hu/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Fekete Ádám Zsolt <fadam@egbcsoport.hu>
 * @author Hamp Gábor <gabor.hamp@gmail.com>
 * @author Sandor TIHANYI <stihanyi+dw@gmail.com>
 * @author Siaynoq Mage <siaynoqmage@gmail.com>
 * @author schilling.janos <schilling.janos@gmail.com>
 * @author Szabó Dávid <szabo.david@gyumolcstarhely.hu>
 * @author Marton Sebok <sebokmarton@gmail.com>
 * @author Serenity87HUN <anikototh87@gmail.com>
 * @author Marina Vladi <deldadam@gmail.com>
 */
$lang['menu']                  = 'Felhasználók kezelése';
$lang['noauth']                = '(A felhasználói azonosítás nem működik.)';
$lang['nosupport']             = '(A felhasználók kezelése nem támogatott.)';
$lang['badauth']               = 'nem érvényes autentikációs technika';
$lang['user_id']               = 'Felhasználói azonosító';
$lang['user_pass']             = 'Jelszó';
$lang['user_name']             = 'Név';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Csoportok';
$lang['field']                 = 'Mező';
$lang['value']                 = 'Érték';
$lang['add']                   = 'Hozzáadás';
$lang['delete']                = 'Törlés';
$lang['delete_selected']       = 'Kiválasztottak törlése';
$lang['edit']                  = 'Szerkesztés';
$lang['edit_prompt']           = 'A felhasználó szerkesztése';
$lang['modify']                = 'Változások mentése';
$lang['search']                = 'Keresés';
$lang['search_prompt']         = 'Keresés';
$lang['clear']                 = 'Keresési szűrés törlése';
$lang['filter']                = 'Szűrés';
$lang['export_all']            = 'Összes felhasználó exportálása (CSV)';
$lang['export_filtered']       = 'Kiválasztott felhasználók exportálása (CSV)';
$lang['import']                = 'Új felhasználók importálása';
$lang['line']                  = 'Sor száma';
$lang['error']                 = 'Hibaüzenet';
$lang['summary']               = '%1$d-%2$d. felhasználók megjelenítése a(z) %3$d megtalált felhasználóból. %4$d felhasználó van összesen.';
$lang['nonefound']             = 'Nincs ilyen felhasználó. %d felhasználó van összesen.';
$lang['delete_ok']             = '%d felhasználó törölve.';
$lang['delete_fail']           = '%d felhasználót nem sikerült törölni.';
$lang['update_ok']             = 'A felhasználó adatait sikeresen elmentettem.';
$lang['update_fail']           = 'A felhasználó adatainak mentése nem sikerült.';
$lang['update_exists']         = 'A felhasználói azonosító változtatása nem sikerült, a megadott azonosító (%s) már létezik. (A többi változtatás mentve.)';
$lang['start']                 = 'első';
$lang['prev']                  = 'előző';
$lang['next']                  = 'következő';
$lang['last']                  = 'utolsó';
$lang['edit_usermissing']      = 'A kiválasztott felhasználót nem találom, a felhasználói nevét törölték vagy megváltoztatták.';
$lang['user_notify']           = 'Felhasználó értesítése';
$lang['note_notify']           = 'Csak akkor küld értesítő e-mailt, ha a felhasználó új jelszót kapott.';
$lang['note_group']            = 'Ha nincs csoport meghatározva, az új felhasználó az alapértelmezett csoportba (%s) kerül.';
$lang['note_pass']             = 'Ha a baloldali mező üres és a felhasználó értesítés aktív, akkor a jelszót a rendszer generálja.';
$lang['add_ok']                = 'A felhasználó sikeresen hozzáadva.';
$lang['add_fail']              = 'A felhasználó hozzáadása nem sikerült.';
$lang['notify_ok']             = 'Értesítő levél elküldve.';
$lang['notify_fail']           = 'Nem sikerült az értesítő levelet elküldeni.';
$lang['import_userlistcsv']    = 'Felhasználók listájának fájlja (CSV)';
$lang['import_header']         = 'Legutóbbi importálás - Hibák';
$lang['import_success_count']  = 'Felhasználók importálása: %d felhasználót találtunk, ebből %d sikeresen importálva.';
$lang['import_failure_count']  = 'Felhasználók importálása: %d sikertelen. A sikertelenség okait lejjebb találod.';
$lang['import_error_fields']   = 'Túl kevés mezőt adtál meg, %d darabot találtunk, legalább 4-re van szükség.';
$lang['import_error_baduserid'] = 'Felhasználói azonosító hiányzik';
$lang['import_error_badname']  = 'Helytelen név';
$lang['import_error_badmail']  = 'Helytelen e-mailcím';
$lang['import_error_upload']   = 'Sikertelen importálás. A csv fájl nem feltölthető vagy üres.';
$lang['import_error_readfail'] = 'Sikertelen importálás. A feltöltött fájl nem olvasható.';
$lang['import_error_create']   = 'Ez a felhasználó nem hozható létre';
$lang['import_notify_fail']    = 'Az értesítő e-mail nem küldhető el az alábbi importált felhasználónak: %s e-mailcíme: %s.';
$lang['import_downloadfailures'] = 'Töltsd le a hibákat tartalmazó fájlt CSV formátumban, hogy ki tudd javítani a hibákat';
$lang['addUser_error_missing_pass'] = 'Adj meg egy jelszót, vagy aktiváld a felhasználói értesítéseket, hogy engedélyezd a jelszógenerálást.';
$lang['addUser_error_pass_not_identical'] = 'A begépelt jelszavak különböznek.';
$lang['addUser_error_modPass_disabled'] = 'A jelszó megváltoztatása jelenleg nem lehetséges.';
$lang['addUser_error_name_missing'] = 'Adj meg egy nevet az új felhasználónak.';
$lang['addUser_error_modName_disabled'] = 'A nevek módosítása jelenleg nincs engedélyezve.';
$lang['addUser_error_mail_missing'] = 'Add meg az e-mail címét az új felhasználónak.';
$lang['addUser_error_modMail_disabled'] = 'Az e-mail cím módosítása jelenleg nincs engedélyezve.';
$lang['addUser_error_create_event_failed'] = 'Egy bővítmény megakadályozta az új felhasználó létrehozását. Tekintsd át az esetleges további üzeneteket a további információkért.';
